(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     36136,        874]
NotebookOptionsPosition[     34999,        830]
NotebookOutlinePosition[     35379,        846]
CellTagsIndexPosition[     35336,        843]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5709654285657516`*^9, 3.570965431115755*^9}}],

Cell[TextData[{
 "This code reads the data created by \[OpenCurlyDoubleQuote]getdist\
\[CloseCurlyDoubleQuote] (CosmoMC's program that makes contours etc) and \
makes nice Mathematica plots :)\n\nParts of the code (the Confid2D function) \
have been used in the \[OpenCurlyDoubleQuote]",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Interface for CosmoMC\[CloseCurlyDoubleQuote] program (mifcmc). The \
difference between this code and \[OpenCurlyDoubleQuote]mifcmc\
\[CloseCurlyDoubleQuote] is that the latter makes the plots directly from the \
chains but the former gets them from the data created by \
\[OpenCurlyDoubleQuote]getdist\[CloseCurlyDoubleQuote]. Both of them have \
different pros and cons, but the results should be more or less the same. \n\n\
Created by Savvas Nesseris 2012-2013. "
}], "Text",
 CellChangeTimes->{{3.5709697588785763`*^9, 3.570969993630907*^9}, {
  3.570970036858968*^9, 3.5709701871851797`*^9}, {3.571031675809038*^9, 
  3.571031699383072*^9}},
 Background->GrayLevel[0.85]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Load", " ", "some", " ", "stuff"}], " ", "//", " ", 
    RowBox[{"Define", " ", "the", " ", "main", " ", "function"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<ComputationalGeometry`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Off", "[", 
     StyleBox[
      RowBox[{"CompiledFunction", "::", "cflist"}], "MessageName"], 
     StyleBox["]", "MessageName"]}], 
    StyleBox[";", "MessageName"]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", 
     RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Confid2D", "[", 
     RowBox[{"data_List", ",", "color_", ",", "inter_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cv", ",", "cv1", ",", "cv2", ",", "qq"}], "}"}], ",", 
      RowBox[{
       RowBox[{"cv", "=", 
        RowBox[{"ConvexHull", "[", 
         RowBox[{"data", ",", 
          RowBox[{"AllPoints", "\[Rule]", "True"}]}], "]"}]}], ";", 
       RowBox[{"cv1", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"data", "[", 
           RowBox[{"[", "#", "]"}], "]"}], "&"}], "/@", "cv"}]}], ";", 
       RowBox[{"cv2", "=", 
        RowBox[{"Join", "[", 
         RowBox[{"cv1", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"cv1", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"cv1", "[", 
             RowBox[{"[", 
              RowBox[{"-", "1"}], "]"}], "]"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"qq", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"color", ",", 
             RowBox[{"FilledCurve", "[", 
              RowBox[{"BSplineCurve", "[", 
               RowBox[{"cv2", ",", 
                RowBox[{"SplineDegree", "\[Rule]", "inter"}], ",", 
                RowBox[{"SplineKnots", "\[Rule]", "\"\<Unclamped\>\""}], ",", 
                RowBox[{"SplineClosed", "\[Rule]", "True"}]}], "]"}], "]"}], 
             ",", 
             RowBox[{"Antialiasing", "\[Rule]", "True"}]}], "}"}], "]"}], ",", 
          RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]}], ";", "qq"}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.570799392608719*^9, {3.5708111030221434`*^9, 3.570811104033145*^9}, {
   3.5708116537209187`*^9, 3.5708116541009197`*^9}, 3.570965422914744*^9, {
   3.5709690698166046`*^9, 3.570969088299631*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "obspkg"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\\"PlotLegends`\\\"\\)\[NoBreak] is now \
obsolete. The legacy version being loaded may conflict with current \
Mathematica functionality. See the Compatibility Guide for updating \
information.\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.570971633313219*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Import", " ", "the", " ", "names", " ", "of", " ", "the", " ", 
    "parameters"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "Import", "[", "\"\<.\\\\plot_data\\\\long_2_params\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.5709682580584593`*^9, 3.5709682799124904`*^9}, {
  3.5709690913596354`*^9, 3.5709690991816463`*^9}, {3.5709694647061615`*^9, 
  3.570969468807167*^9}}],

Cell[BoxData["\<\"           1 \\\\Omega_b h^2\\n           2 \\\\Omega_{DM} \
h^2\\n           3 \\\\theta\\n           4 \\\\tau\\n           5 \
\\\\Omega_K\\n           7 w\\n           8 n_s\\n          11 log[10^{10} \
A_s]\\n          13 A_{SZ}\\n          14 \\\\Omega_\\\\Lambda\\n          15 \
Age/Gyr\\n          16 \\\\Omega_m\\n          18 z_{re}\\n          20 H_0\"\
\>"], "Output",
 CellChangeTimes->{3.570968280402491*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "filenames", " ", "for", " ", "2", " ", "params"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "FileNames", "[", "\"\<.\\\\plot_data\\\\long_2_2D_8_1*\>\"", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.570968289064503*^9, 3.570968340002575*^9}, 
   3.5709686424470015`*^9, {3.5709694737071743`*^9, 3.570969484119189*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\".\\\\plot_data\\\\long_2_2D_8_1\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_2D_8_1_cont\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_2D_8_1_likes\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.5709683013565207`*^9, 3.570968303626524*^9}, {
   3.570968335091568*^9, 3.5709683404125757`*^9}, 3.570968642847002*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<.\\\\plot_data\\\\long_2_p*.dat\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5709683749596243`*^9, 3.5709683851306386`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\".\\\\plot_data\\\\long_2_p11.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p13.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p14.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p15.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p16.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p18.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p1.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p20.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p2.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p3.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p4.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p5.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p7.dat\"\>", 
   ",", "\<\".\\\\plot_data\\\\long_2_p8.dat\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.570968375439625*^9, 3.570968385571639*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Import", " ", "the", " ", "data", " ", "and", " ", "make", " ", "the", 
    " ", "plot"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Confid2D", "[", 
     RowBox[{
      StyleBox[
       RowBox[{
        StyleBox["data",
         FontColor->RGBColor[1, 0, 0]], "_List"}]], ",", 
      StyleBox[
       RowBox[{
        StyleBox["color",
         FontColor->RGBColor[1, 0.5, 0]], "_"}]], ",", 
      StyleBox[
       RowBox[{
        StyleBox["inter",
         FontColor->RGBColor[0.5, 0, 0.5]], "_"}]]}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     StyleBox["data",
      FontColor->RGBColor[1, 0, 0]], " ", ":", " ", 
     RowBox[{
     "is", " ", "the", " ", "data", " ", "that", " ", "make", " ", "the", " ",
       "plot"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     StyleBox["color",
      FontColor->RGBColor[1, 0.5, 0]], " ", ":", " ", 
     RowBox[{"is", " ", "obviosuly", " ", "a", " ", "color"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      StyleBox["inter",
       FontColor->RGBColor[0.5, 0, 0.5]], " ", ":", " ", 
      RowBox[{"is", " ", "the", " ", "interpolation"}]}], " ", "//", " ", 
     RowBox[{"change", " ", "the", " ", "number", " ", "eg", " ", 
      RowBox[{"in", " ", "[", 
       RowBox[{"2", ",", "15"}], "]"}], " ", "to", " ", "make", " ", "the", 
      " ", "contour", " ", "as", " ", "smoooth", " ", "as", " ", 
      "possible"}]}], ";"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{
     "f1", ",", "f2", ",", "f3", ",", "f4", ",", "x1", ",", "x2", ",", "data",
       ",", "data1"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f1", "=", 
     RowBox[{
     "Import", "[", "\"\<.\\\\plot_data\\\\long_2_2D_8_1\>\"", "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f2", "=", 
     RowBox[{"Import", "[", 
      RowBox[{
      "\"\<.\\\\plot_data\\\\long_2_2D_8_1_cont\>\"", ",", "\"\<Table\>\""}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f3", "=", 
     RowBox[{
     "Import", "[", "\"\<.\\\\plot_data\\\\long_2_p1.dat\>\"", "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f4", "=", 
     RowBox[{
     "Import", "[", "\"\<.\\\\plot_data\\\\long_2_p8.dat\>\"", "]"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x1", "=", 
     RowBox[{"f4", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"x2", "=", 
     RowBox[{"f3", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x1", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"x2", "[", 
          RowBox[{"[", "j", "]"}], "]"}], ",", 
         RowBox[{"f1", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "x1", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "x2", "]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"data1", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", "data", "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ">", 
         RowBox[{"f2", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "&"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"data2", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Partition", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", "data", "]"}], ",", "3"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ">", 
         RowBox[{"f2", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "&"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{"sh1", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"Confid2D", "[", 
       RowBox[{
        RowBox[{"data2", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"Hue", "[", 
         RowBox[{".2", ",", ".2", ",", ".3"}], "]"}], ",", "10"}], "]"}], ",", 
      RowBox[{"Confid2D", "[", 
       RowBox[{
        RowBox[{"data1", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"Hue", "[", 
         RowBox[{".2", ",", ".4", ",", ".8"}], "]"}], ",", "10"}], "]"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.93", ",", "1.01"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.021", ",", "0.0242"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*SubscriptBox[\(n\), \(s\)]\)\>\"", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[CapitalOmega]\), \
\(b\)]\)\!\(\*SuperscriptBox[\(h\), \(2\)]\)\>\""}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FontSize", "\[Rule]", "18"}], "}"}]}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{".5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRangeClipping", "\[Rule]", "True"}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5707971541436863`*^9, 3.570797199936305*^9}, {
  3.570797772986082*^9, 3.570797788733982*^9}, {3.5707982049867907`*^9, 
  3.5707982070089064`*^9}, {3.570811162602227*^9, 3.5708112920034094`*^9}, {
  3.5708113247484555`*^9, 3.5708114739226656`*^9}, {3.570965343551632*^9, 
  3.570965344801634*^9}, {3.5709654142027316`*^9, 3.5709654437977734`*^9}, {
  3.5709663380192175`*^9, 3.5709663538232403`*^9}, {3.570968353014593*^9, 
  3.5709683602166033`*^9}, {3.5709683971536555`*^9, 3.5709684226486917`*^9}, {
  3.5709684751787653`*^9, 3.570968546460866*^9}, {3.5709686474570084`*^9, 
  3.5709687155581045`*^9}, {3.570969132476693*^9, 3.5709691391787024`*^9}, {
  3.5709694882301946`*^9, 3.5709694945412035`*^9}, {3.5709695390182657`*^9, 
  3.570969659430436*^9}, {3.570969944011837*^9, 3.570969945052839*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.2, 0.2, 0.3], FilledCurveBox[BSplineCurve[CompressedData["
1:eJxTTMoPSmViYGCQAmIQ7fzs1IJbCh/sA5vkAyusZ9jD+CuvrewXzkDwGbRN
zq2bMsN+x+m6uy/5EHyD7yrcn3++h/MDltvsEryG4FsXLTE22ITgRyvteeTX
h+D3n7j06Pmtd/ZbAq7XOz2abj/LOYhbdfI7e3H5/nU8ndPtn8gxTprP/M5e
X/hVX1btNDj/+r74gPMBCH5D1lVBExUE36pXvH7m96lw/mOLXod/p6baH8l7
+ahBHcG/tbgxM8kbwd/1OXOXcz6CD3MfzLx8id3GJ/8h7Ku+dHlibtZ7+5IP
yxVZV02D+++Mi1HCgmvT4P5XnrlnnjXzdHh4wfyHHv7o8gBI0s2b
      "], SplineDegree -> 10, SplineKnots -> "Unclamped", SplineClosed -> 
      True]], 
    StyleBox[{},
     Antialiasing->True]}, 
   {Hue[0.2, 0.4, 0.8], 
    FilledCurveBox[
     BSplineCurve[{{0.9905015, 0.02315389}, {0.9905015, 0.02332405}, {
      0.9905015, 0.02349421}, {0.9861216, 0.02349421}, {0.9773617, 
      0.02332405}, {0.9642219, 0.02298374}, {0.959842, 0.02281358}, {
      0.9510821, 0.02230311}, {0.9510821, 0.02213295}, {0.9510821, 
      0.0219628}, {0.9510821, 0.02179264}, {0.955462, 0.02179264}, {0.959842, 
      0.02179264}, {0.9773617, 0.02230311}, {0.9817417, 0.02247327}, {
      0.9861216, 0.02281358}, {0.9905015, 0.02315389}, {0.9861216, 
      0.02281358}}, SplineDegree -> 10, SplineKnots -> "Unclamped", 
      SplineClosed -> True]], 
    StyleBox[{},
     Antialiasing->True]}},
  AspectRatio->1,
  BaseStyle->{FontSize -> 18},
  Epilog->{
    Dashing[{Small, Small}], 
    LineBox[{{0, 0}, {0.5, 0}}]},
  Frame->True,
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(n\\), \\(s\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \
\\(b\\)]\\)\\!\\(\\*SuperscriptBox[\\(h\\), \\(2\\)]\\)\"", TraditionalForm]},
  PlotRange->{{0.93, 1.01}, {0.021, 0.0242}},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.5708114248045964`*^9, 3.5708114745426664`*^9}, 
   3.570965314706591*^9, 3.570965346361636*^9, {3.5709653819676857`*^9, 
   3.5709653962497063`*^9}, {3.570965440017768*^9, 3.570965445847776*^9}, {
   3.5709663401992207`*^9, 3.5709663543632407`*^9}, {3.5709684052146673`*^9, 
   3.5709684259496965`*^9}, {3.5709685100648146`*^9, 
   3.5709685480408683`*^9}, {3.5709686508280134`*^9, 3.570968716069105*^9}, 
   3.570969140158704*^9, 3.570971638504226*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Make", " ", "another", " ", "plot"}], " ", "//", " ", 
      RowBox[{
      "In", " ", "this", " ", "case", " ", "some", " ", "mock", " ", 
       "contour", " ", "2"}]}], " ", "//", " ", 
     RowBox[{"Poor", " ", "constraints"}]}], ",", " ", 
    RowBox[{"very", " ", "degenerate"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"sh2", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", ".98"}], ")"}], "^", "2"}], "+", 
       RowBox[{"10", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "-", "0.0225"}], ")"}], "^", "2"}]}]}], "\[Equal]", 
      ".0002"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0.93", ",", "1.01"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0.021", ",", "0.0242"}], "}"}], ",", 
     RowBox[{"ContourStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Dashed", ",", 
        "Blue"}], "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.570970219800226*^9, 3.570970261028284*^9}, {
  3.570971605108179*^9, 3.5709716860322933`*^9}}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJw91Hs4VPkfwHEpl6emi4xb0i8hocuPpFzqI9tFg0JPuiLdZFxal22RLGpp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   "], {{}, {}, 
    TagBox[
     TooltipBox[
      {RGBColor[0, 0, 1], Thickness[0.005], Dashing[{Small, Small}], 
       LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
         19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 
        53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 
        70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85}], 
       LineBox[{86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 
        101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 
        115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 
        129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 
        143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 
        157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 
        170}]},
      RowBox[{
        RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
             RowBox[{
               RowBox[{"-", "0.98`"}], "+", "x"}], ")"}], "2"], "+", 
          RowBox[{"10", " ", 
            SuperscriptBox[
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"-", "0.0225`"}], "+", "y"}], ")"}], "2"]}]}], 
        "\[Equal]", "0.0002`"}]],
     Annotation[#, (-0.98 + $CellContext`x)^2 + 
       10 (-0.0225 + $CellContext`y)^2 == 0.0002, "Tooltip"]& ]}],
  AspectRatio->1,
  Frame->True,
  Method->{},
  PlotRange->{{0.93, 1.01}, {0.021, 0.0242}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5709702556162767`*^9, 3.5709702613382845`*^9}, 
   3.5709716424352317`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Combine", " ", "2", " ", "plots", " ", 
    RowBox[{"(", 
     RowBox[{"contour", " ", "1", " ", "and", " ", "contour", " ", "2"}], 
     ")"}], " ", "and", " ", "add", " ", "legend"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Change", " ", "contour", " ", "2", " ", "with", " ", "some", " ", "other",
     " ", "plots", " ", "if", " ", "you", " ", "want"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"ShowLegend", "[", 
   RowBox[{
    RowBox[{"Show", "[", 
     RowBox[{"sh1", ",", "sh2", ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.93", ",", "1.01"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.021", ",", "0.0242"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*SubscriptBox[\(n\), \(s\)]\)\>\"", ",", 
         "\"\<\!\(\*SubscriptBox[\(\[CapitalOmega]\), \
\(b\)]\)\!\(\*SuperscriptBox[\(h\), \(2\)]\)\>\""}], "}"}]}], ",", 
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"FontSize", "\[Rule]", "18"}], "}"}]}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Dashed", ",", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{".5", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Hue", "[", 
              RowBox[{".2", ",", ".4", ",", ".8"}], "]"}], ",", 
             RowBox[{"Disk", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"Scaled", "[", ".3", "]"}]}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<CosmoMC Sample\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Dashed", ",", "Blue", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"2", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], 
           "]"}], ",", "\"\<Contour 2\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"LegendSize", "\[Rule]", ".55"}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", ".6"}], ",", ".35"}], "}"}]}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.570803182474487*^9, 3.570803200070493*^9}, {
  3.5708032412008457`*^9, 3.570803472385069*^9}, {3.57081149128469*^9, 
  3.5708116310278873`*^9}, {3.570968744474145*^9, 3.5709688372622757`*^9}, {
  3.5709688729393263`*^9, 3.5709689097573786`*^9}, {3.570968992222495*^9, 
  3.5709690600745907`*^9}, {3.5709691528607216`*^9, 3.570969448823139*^9}, {
  3.5709694995512104`*^9, 3.570969529437253*^9}, {3.5709697167525167`*^9, 
  3.570969752107567*^9}, {3.570970210899214*^9, 3.570970242034257*^9}, {
  3.5709716512162437`*^9, 3.5709716627182603`*^9}, {3.570971700895314*^9, 
  3.570971714897334*^9}},
 CellID->1424996800],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{{
       {Hue[0.2, 0.2, 0.3], FilledCurveBox[BSplineCurve[CompressedData["
1:eJxTTMoPSmViYGCQAmIQ7fzs1IJbCh/sA5vkAyusZ9jD+CuvrewXzkDwGbRN
zq2bMsN+x+m6uy/5EHyD7yrcn3++h/MDltvsEryG4FsXLTE22ITgRyvteeTX
h+D3n7j06Pmtd/ZbAq7XOz2abj/LOYhbdfI7e3H5/nU8ndPtn8gxTprP/M5e
X/hVX1btNDj/+r74gPMBCH5D1lVBExUE36pXvH7m96lw/mOLXod/p6baH8l7
+ahBHcG/tbgxM8kbwd/1OXOXcz6CD3MfzLx8id3GJ/8h7Ku+dHlibtZ7+5IP
yxVZV02D+++Mi1HCgmvT4P5XnrlnnjXzdHh4wfyHHv7o8gBI0s2b
          "], SplineDegree -> 10, SplineKnots -> "Unclamped", SplineClosed -> 
          True]], 
        StyleBox[{},
         Antialiasing->True]}, 
       {Hue[0.2, 0.4, 0.8], 
        FilledCurveBox[
         BSplineCurve[{{0.9905015, 0.02315389}, {0.9905015, 0.02332405}, {
          0.9905015, 0.02349421}, {0.9861216, 0.02349421}, {0.9773617, 
          0.02332405}, {0.9642219, 0.02298374}, {0.959842, 0.02281358}, {
          0.9510821, 0.02230311}, {0.9510821, 0.02213295}, {0.9510821, 
          0.0219628}, {0.9510821, 0.02179264}, {0.955462, 0.02179264}, {
          0.959842, 0.02179264}, {0.9773617, 0.02230311}, {0.9817417, 
          0.02247327}, {0.9861216, 0.02281358}, {0.9905015, 0.02315389}, {
          0.9861216, 0.02281358}}, SplineDegree -> 10, SplineKnots -> 
          "Unclamped", SplineClosed -> True]], 
        StyleBox[{},
         Antialiasing->True]}}, GraphicsComplexBox[CompressedData["
1:eJw91Hs4VPkfwHEpl6emi4xb0i8hocuPpFzqI9tFg0JPuiLdZFxal22RLGpp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       "], {{}, {}, 
        TagBox[
         TooltipBox[
          {RGBColor[0, 0, 1], Thickness[0.005], Dashing[{Small, Small}], 
           LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,
             18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
            34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 
            50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
            66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 
            82, 83, 84, 85}], 
           LineBox[{86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
            100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
            113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 
            126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 
            139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 
            152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
            165, 166, 167, 168, 169, 170}]},
          RowBox[{
            RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                 RowBox[{
                   RowBox[{"-", "0.98`"}], "+", "x"}], ")"}], "2"], "+", 
              RowBox[{"10", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "0.0225`"}], "+", "y"}], ")"}], "2"]}]}], 
            "\[Equal]", "0.0002`"}]],
         Annotation[#, (-0.98 + $CellContext`x)^2 + 
           10 (-0.0225 + $CellContext`y)^2 == 0.0002, "Tooltip"]& ]}]},
     AspectRatio->1,
     BaseStyle->{FontSize -> 18},
     Epilog->{
       Dashing[{Small, Small}], 
       LineBox[{{0, 0}, {0.5, 0}}]},
     Frame->True,
     FrameLabel->{
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(n\\), \\(s\\)]\\)\"", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \
\\(b\\)]\\)\\!\\(\\*SuperscriptBox[\\(h\\), \\(2\\)]\\)\"", TraditionalForm]},
     ImageSize->500,
     PlotRange->{{0.93, 1.01}, {0.021, 0.0242}},
     PlotRangeClipping->True], {-1, -1.}, {Left, Bottom}, {2, 2.}], 
   GraphicsGroupBox[{
     {GrayLevel[0], 
      RectangleBox[{-0.6, 0.35}, {-0.050000000000000044`, 0.7625}]}, 
     {GrayLevel[1], EdgeForm[{GrayLevel[0], Thickness[0.001]}], 
      GraphicsGroupBox[{
        RectangleBox[{-0.6, 0.35}, {-0.050000000000000044`, 0.7625}], InsetBox[
         GraphicsBox[{{{InsetBox[
              GraphicsBox[
               {RGBColor[0, 0, 1], Dashing[{Small, Small}], 
                LineBox[{{0, 0}, {2, 0}}]}], {0.08, 0.08}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"Contour 2\"\>", {1.2100000000000002`, 0.58}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[
               {Hue[0.2, 0.4, 0.8], 
                DiskBox[{0, 0}, Scaled[0.3]]}], {0.08, 1.24}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"CosmoMC Sample\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
               Automatic, {1, 0}]}}, {}},
          AspectRatio->0.7500000000000001,
          PlotRange->{{-0.1, 3.26}, {-0.1, 2.42}}], {-0.6, 0.35}, {
         Left, Bottom}, {0.5499999999999999, 0.41250000000000003`}]}]}}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->500.,
  PlotRange->All]], "Output",
 CellChangeTimes->{{3.5708031785002594`*^9, 3.570803201778591*^9}, {
   3.570803242611926*^9, 3.5708034746091957`*^9}, {3.5708115094477158`*^9, 
   3.570811516739726*^9}, {3.5708115801498156`*^9, 3.5708116322978888`*^9}, 
   3.5709654787648225`*^9, 3.5709663628442526`*^9, {3.570968759347166*^9, 
   3.570968838683278*^9}, {3.570968878840335*^9, 3.570968911308381*^9}, {
   3.5709689951924987`*^9, 3.570969061544593*^9}, {3.570969145009711*^9, 
   3.5709691549317245`*^9}, {3.570969227533827*^9, 3.5709692731618915`*^9}, {
   3.570969304607936*^9, 3.570969334532978*^9}, {3.5709694308601136`*^9, 
   3.5709694502931414`*^9}, {3.5709697182825193`*^9, 3.5709697535485687`*^9}, 
   3.5709702703192973`*^9, 3.5709716685492687`*^9}]
}, Open  ]]
},
WindowSize->{1911, 927},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
Magnification->1.7000000476837158`,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 120, 2, 50, "Input"],
Cell[680, 24, 1018, 18, 272, "Text"],
Cell[CellGroupData[{
Cell[1723, 46, 2697, 70, 339, "Input"],
Cell[4423, 118, 403, 9, 38, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4863, 132, 446, 10, 83, "Input"],
Cell[5312, 144, 441, 6, 440, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5790, 155, 401, 9, 83, "Input"],
Cell[6194, 166, 358, 6, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6589, 177, 173, 3, 56, "Input"],
Cell[6765, 182, 850, 16, 158, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7652, 203, 7063, 193, 757, "Input"],
Cell[14718, 398, 2226, 46, 630, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16981, 449, 1257, 35, 130, "Input"],
Cell[18241, 486, 4629, 87, 687, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22907, 578, 3727, 92, 249, "Input",
 CellID->1424996800],
Cell[26637, 672, 8346, 155, 991, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
